function [x,flag]=punto_fisso(x0,maxit,tol,g)
% INPUT.
% x0      : PUNTO INIZIALE (VETTORE COLONNA).
% maxit   : NUMERO MASSIMO DI ITERAZIONI.
% tol     : TOLLERANZA CRITERIO DI ARRESTO.
% g       : EQUAZIONE DA RISOLVERE x=g(x)
% OUTPUT.
% x       : ITERAZIONI PUNTO FISSO.
% flag    : 0: TERMINAZIONE CORRETTA, 1: NON CORRETTA.

x=x0; flag=0;
for index=1:maxit
    x(:,end+1)=feval(g,x(:,end)); 
    if norm(x(:,end)-x(:,end-1),inf) < tol, return; end
end
flag=1;